LendingLines

Struct LendingLines 

pub struct LendingLines<'a, R: BufRead> { /* private fields */ }
A lending iterator over the lines of a BufRead reader.

See BufReadExt::lending_lines for more details.

Implementations

Source

impl<'a, R: BufRead> LendingLines<'a, R>

pub fn next(&mut self) -> Option<Result<&str>>

Returns the next line from the reader, or None if the end of the file has been reached. The returned string slice is valid until the next call to next.